@@ -59,6 +59,7 @@ __all__ = (
     "LifecycleEventTypeDef",
     "InstanceSummaryTypeDef",
     "BatchGetDeploymentInstancesOutputTypeDef",
+    "CloudFormationTargetTypeDef",
     "ECSTaskSetTypeDef",
     "ECSTargetTypeDef",
     "InstanceTargetTypeDef",
@@ -274,7 +275,7 @@ LastDeploymentInfoTypeDef = TypedDict(
     {
         "deploymentId": str,
         "status": Literal[
-            "Created", "Queued", "InProgress", "Succeeded", "Failed", "Stopped", "Ready"
+            "Created", "Queued", "InProgress", "Baking", "Succeeded", "Failed", "Stopped", "Ready"
         ],
         "endTime": datetime,
         "createTime": datetime,
@@ -426,6 +427,22 @@ BatchGetDeploymentInstancesOutputTypeDef = TypedDict(
     total=False,
 )
 
+CloudFormationTargetTypeDef = TypedDict(
+    "CloudFormationTargetTypeDef",
+    {
+        "deploymentId": str,
+        "targetId": str,
+        "lastUpdatedAt": datetime,
+        "lifecycleEvents": List[LifecycleEventTypeDef],
+        "status": Literal[
+            "Pending", "InProgress", "Succeeded", "Failed", "Skipped", "Unknown", "Ready"
+        ],
+        "resourceType": str,
+        "targetVersionWeight": float,
+    },
+    total=False,
+)
+
 ECSTaskSetTypeDef = TypedDict(
     "ECSTaskSetTypeDef",
     {
@@ -504,10 +521,13 @@ LambdaTargetTypeDef = TypedDict(
 DeploymentTargetTypeDef = TypedDict(
     "DeploymentTargetTypeDef",
     {
-        "deploymentTargetType": Literal["InstanceTarget", "LambdaTarget", "ECSTarget"],
+        "deploymentTargetType": Literal[
+            "InstanceTarget", "LambdaTarget", "ECSTarget", "CloudFormationTarget"
+        ],
         "instanceTarget": InstanceTargetTypeDef,
         "lambdaTarget": LambdaTargetTypeDef,
         "ecsTarget": ECSTargetTypeDef,
+        "cloudFormationTarget": CloudFormationTargetTypeDef,
     },
     total=False,
 )
@@ -568,6 +588,7 @@ ErrorInformationTypeDef = TypedDict(
             "REVISION_MISSING",
             "THROTTLED",
             "TIMEOUT",
+            "CLOUDFORMATION_STACK_FAILURE",
         ],
         "message": str,
     },
@@ -600,7 +621,7 @@ DeploymentInfoTypeDef = TypedDict(
         "previousRevision": RevisionLocationTypeDef,
         "revision": RevisionLocationTypeDef,
         "status": Literal[
-            "Created", "Queued", "InProgress", "Succeeded", "Failed", "Stopped", "Ready"
+            "Created", "Queued", "InProgress", "Baking", "Succeeded", "Failed", "Stopped", "Ready"
         ],
         "errorInformation": ErrorInformationTypeDef,
         "createTime": datetime,
@@ -608,7 +629,14 @@ DeploymentInfoTypeDef = TypedDict(
         "completeTime": datetime,
         "deploymentOverview": DeploymentOverviewTypeDef,
         "description": str,
-        "creator": Literal["user", "autoscaling", "codeDeployRollback"],
+        "creator": Literal[
+            "user",
+            "autoscaling",
+            "codeDeployRollback",
+            "CodeDeploy",
+            "CloudFormation",
+            "CloudFormationRollback",
+        ],
         "ignoreApplicationStopFailures": bool,
         "autoRollbackConfiguration": AutoRollbackConfigurationTypeDef,
         "updateOutdatedInstancesOnly": bool,
@@ -622,6 +650,7 @@ DeploymentInfoTypeDef = TypedDict(
         "fileExistsBehavior": Literal["DISALLOW", "OVERWRITE", "RETAIN"],
         "deploymentStatusMessages": List[str],
         "computePlatform": Literal["Server", "Lambda", "ECS"],
+        "externalId": str,
     },
     total=False,
 )
